GOOF----LE-8-2.0$      ]l 4  h      ] g  guile	 	g  define-module*	 	 	g  language	g  tree-il	g  
primitives		 	
g  filenameS	f  language/tree-il/primitives.scm	g  importsS	
g  system	g  base	g  pmatch	
 	 	g  ice-9	g  match	 	 	g  rnrs	g  bytevectors	 	 	g  syntax	
 	 	 	 	g  srfi	 g  srfi-4	!  	"! 	#g  srfi-16	$# 	%$ 	&"% 	'g  exportsS	(g  resolve-primitives!	)g  add-interesting-primitive!	*g  expand-primitives!	+g  effect-free-primitive?	,g   effect+exception-free-primitive?	-g  constructor-primitive?	.g  accessor-primitive?	/g  singly-valued-primitive?	0g  bailout-primitive?	1g  negate-primitive	2()*+,-./01 
	3g  set-current-module	43 	53 	6g  apply	7g  @apply	8g  call-with-values	9g  @call-with-values	:g  call-with-current-continuation	;g  @call-with-current-continuation	<g  call/cc	=g  dynamic-wind	>g  
@dynamic-wind	?g  values	@g  eq?	Ag  eqv?	Bg  equal?	Cg  memq	Dg  memv	Eg  =	Fg  <	Gg  >	Hg  <=	Ig  >=	Jg  zero?	Kg  	positive?	Lg  	negative?	Mg  +	Ng  *	Og  -	Pg  /	Qg  1-	Rg  1+	Sg  quotient	Tg  	remainder	Ug  modulo	Vg  ash	Wg  logand	Xg  logior	Yg  logxor	Zg  lognot	[g  not	\g  pair?	]g  null?	^g  list?	_g  symbol?	`g  vector?	ag  string?	bg  struct?	cg  number?	dg  char?	eg  complex?	fg  real?	gg  	rational?	hg  inf?	ig  nan?	jg  integer?	kg  exact?	lg  inexact?	mg  even?	ng  odd?	og  char<?	pg  char<=?	qg  char>=?	rg  char>?	sg  
integer->char	tg  
char->integer	ug  number->string	vg  string->number	wg  acons	xg  cons	yg  cons*	zg  list	{g  vector	|g  car	}g  cdr	~g  set-car!	g  set-cdr! g  caar g  cadr g  cdar g  cddr g  caaar g  caadr g  cadar g  caddr g  cdaar g  cdadr g  cddar g  cdddr g  caaaar g  caaadr g  caadar g  caaddr g  cadaar g  cadadr g  caddar g  cadddr g  cdaaar g  cdaadr g  cdadar g  cdaddr g  cddaar g  cddadr g  cdddar g  cddddr g  
vector-ref g  vector-set! g  variable-ref g  
variable-set! g  variable-bound? g  	fluid-ref g  
fluid-set! g  @prompt g  call-with-prompt g  @abort g  abort-to-prompt g  make-prompt-tag g  throw g  error g  	scm-error g  
string-length g  
string-ref g  string-set! g  
struct-vtable g  make-struct g  
struct-ref g  struct-set! g  bytevector-u8-ref g  bytevector-u8-set! g  bytevector-s8-ref g  bytevector-s8-set! g  u8vector-ref g  
u8vector-set! g  s8vector-ref g  
s8vector-set! g  bytevector-u16-ref g  bytevector-u16-set! g  bytevector-u16-native-ref g  bytevector-u16-native-set! g  bytevector-s16-ref g  bytevector-s16-set! g  bytevector-s16-native-ref g  bytevector-s16-native-set! g  
u16vector-ref g  u16vector-set! g  
s16vector-ref g  s16vector-set! g  bytevector-u32-ref g  bytevector-u32-set! g  bytevector-u32-native-ref g  bytevector-u32-native-set! g  bytevector-s32-ref g  bytevector-s32-set! g  bytevector-s32-native-ref g  bytevector-s32-native-set! g  
u32vector-ref g  u32vector-set! g  
s32vector-ref g  s32vector-set! g  bytevector-u64-ref g  bytevector-u64-set! g  bytevector-u64-native-ref g  bytevector-u64-native-set! g  bytevector-s64-ref g  bytevector-s64-set! g  bytevector-s64-native-ref g  bytevector-s64-native-set! g  
u64vector-ref g  u64vector-set! g  
s64vector-ref g  s64vector-set! g  bytevector-ieee-single-ref g  bytevector-ieee-single-set! g  !bytevector-ieee-single-native-ref g  "bytevector-ieee-single-native-set! g  bytevector-ieee-double-ref g  bytevector-ieee-double-set! g  !bytevector-ieee-double-native-ref g  "bytevector-ieee-double-native-set! g  
f32vector-ref g  f32vector-set! g  
f64vector-ref g  f64vector-set! 6789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_`abcdefghijklmnopqrstuvwxyz{|}~  g  *interesting-primitive-names* g  
hashq-set! g  *interesting-primitive-vars* g  module-variable g  current-module f  unbound interesting primitive g  make-hash-table g  for-each g  make-struct/no-tail wxyz{  g  *primitive-constructors* |}CD  g  *primitive-accessors* g  append     g  *effect-free-primitives* ?@AB[\]^_`bacdwxyz{  g  "*effect+exception-free-primitives* 6789:;<=>?  g  *multiply-valued-primitives*  g  *bailout-primitives*mnkloqrp g  *negatable-primitives*g  *effect-free-primitive-table*	g  (*effect+exceptions-free-primitive-table*
g  !*multiply-valued-primitive-table*g  *bailout-primitive-table*g  *negatable-primitive-table*
g  	hashq-refg  post-order!g  <toplevel-ref>g  toplevel-ref-srcg  toplevel-ref-nameg  and=>g  make-primitive-refg  <module-ref>g  module-ref-srcg  module-ref-modg  module-ref-nameg  module-ref-public?g  resolve-moduleg  module-public-interfaceg  identityg  *primitive-expand-table*g  
pre-order!g  
<application>g  application-src g  application-proc!g  application-args"g  primitive-ref?#g  primitive-ref-name$g  make-syntax-transformer%$ &$ 'g  define-primitive-expander(g  macro)g  $sc-dispatch*) +) ,g  _-g  any.,-/g  
syntax->datum0/ 1/ 2g  
datum->syntax32 42 5g  reverse6g  quote7g  
make-const8g  src9g  make-application:g  self-evaluating?;f  	what what<g  if=f  bad consequent yall>g  
match-lambda*?, @g  syntax-violationA@ B@ Cf  -source expression failed to match any patternDg  lengthED FD Gg  lastHG I5 J5 Kg  const?Lg  	const-expMg  gensymNf  bOg  make-lexical-refPg  bQg  make-letRP Sg  make-conditionalTg  chained-comparison-expanderUFGHIE V Wg  most-negative-fixnumXg  most-positive-fixnumYg  maybe-simplify-to-eqZf  pre-[f  thunk-\f  post-]g  pre^g  thunk_g  post`]^_ ag  make-dynwindb]_ cg  make-dynrefdg  make-dynseteg  make-promptfg  make-lambda-casegg  tree-il-srchg  argsig  handlerji kg  
make-abortC 5 hx  b  ]4	
&'25 45 >  "  G   R       h0      ]	445  5$  "  	4 5 6       g  name
		0 g  t		,  g  filenamef  language/tree-il/primitives.scm
	t
		v		
	v	#		v			v		!	w		%	w		)	w		0	u	 
		0  g  nameg  add-interesting-primitive! C)R4i5 R4i)ii>  "  G  RR?@ABEFGHIJKLVWXYZMNOPQRSTU[\]^_`bacdefghijklmnopqrstuv4ii5RRR RR4i5 R4i5 	R4i5 
R4i5 R4i5 R4i     h   l   ] 6     d       g  x
		  g  filenamef  language/tree-il/primitives.scm
 	
	 	 		   Ci>  "  G  4i	     h   l   ] 6     d       g  x
		  g  filenamef  language/tree-il/primitives.scm
 	
	 	 		   Ci>  "  G  4i
     h   l   ] 6     d       g  x
		  g  filenamef  language/tree-il/primitives.scm
 	
	 	 		   Ci>  "  G  4i     h   l   ] 6     d       g  x
		  g  filenamef  language/tree-il/primitives.scm
 	
	 	 		   Ci>  "  G  4i    h(      ]4  >  "  G    6         g  x
		&  g  filenamef  language/tree-il/primitives.scm
 	
	 		
 	4	
 	<	 		! 	4	$ 	<	& 	 			&   Ci>  "  G  C    h      ] 6             g  prim
		
  g  filenamef  language/tree-il/primitives.scm
 
	
 	 		
  g  nameg  constructor-primitive? C-RC    h      ] 6             g  prim
		
  g  filenamef  language/tree-il/primitives.scm
 
	
 	 		
  g  nameg  accessor-primitive? C.R
     h      ] 6             g  prim
		
  g  filenamef  language/tree-il/primitives.scm
 
	
 	 		
  g  nameg  effect-free-primitive? C+R
	  h      ] 6             g  prim
		
  g  filenamef  language/tree-il/primitives.scm
 
	
 	 		
  g  nameg   effect+exception-free-primitive? C,R

        h      ]4 5C          g  prim
		
  g  filenamef  language/tree-il/primitives.scm
 
	 		 	 		
  g  nameg  singly-valued-primitive? C/R
       h      ] 6             g  prim
		
  g  filenamef  language/tree-il/primitives.scm
 
	
 	 		
  g  nameg  bailout-primitive? C0R
      h      ] 6             g  prim
		
  g  filenamef  language/tree-il/primitives.scm
 
	
 	 		
  g  nameg  negate-primitive C1R
   h   o   ]L  6      g       g  name
		
  g  filenamef  language/tree-il/primitives.scm
 		
 	 		
   C
       h   o   ]L  6      g       g  name
		
  g  filenamef  language/tree-il/primitives.scm
 		
	 		
   C      h       ]44 L55L O 6          g  m
		  g  filenamef  language/tree-il/primitives.scm
 		 		
 	#	 		 	 		   C      h   K  ]) &  -4 54 544L 55O 6	&  K4
 54 54 54
 5445$  "  5O 6C       C      g  x
	  g  rtd	  g  src			< g  name			< g  src		`  g  mod		`  g  name		`  g  public?		`   g  filenamef  language/tree-il/primitives.scm
 		 		$ 		) 		3 		< 		D 		k 		n 		z 	  	  	 
	    C  h      ]O  6        g  x
		 g  mod		  g  filenamef  language/tree-il/primitives.scm
 
	 	 			  g  nameg  resolve-primitives! C(R4i5 R !"
# 	     h`   
  ]) &  H4 54 54 545$   4455$  @CCC             g  x
		Y g  rtd		Y g  src		$	W g  proc		$	W g  args		$	W g  expand		C	U  g  filenamef  language/tree-il/primitives.scm
				+	
	5		6		;	&	C		C	
	K		S	 		Y   C        h      ] 6             g  x
		
  g  filenamef  language/tree-il/primitives.scm
	
	

	 		
  g  nameg  expand-primitives! C*R4&'(+.14z5y6789:; 
     h     ]"  (  45C$  445 5C$  F&  "   	  4L 5 "$  "l4
5$   "H6 "4            g  args
	  g  in	  g  out		   g  filenamef  language/tree-il/primitives.scm
									!				
			 		$	$	/		6		7	
	;		>		A	 	D	*	H		J 		O 	.	Q 		X!		c!	L	g!		k"	/	p"	<	s"	/	v!		y	 	
 $	 $	
 	 &	 &	  &	 &	
 '	
 '	 '	
 	 (	 (	  (	2 (	  (	 (	
 *	 *	  *	
 	 	 	 6	   g  nameg  inline-args C<986c7= 
    h0    ]A $    &  $  $  q$  C(  4L 54L 5 C  4L5 C  4L5 C  4L5 C  4L5 C  4L5 C $   C4 5$  
  C $  	 6C            g  exp
	* g  vx	  g  vy		  g  vx		(  g  vy		(  g  vx		9  g  vy		9  g  vx		J  g  vy		J   	g  filenamef  language/tree-il/primitives.scm
+		-			,		.		V0			Y1		`2		i0			l4			v4	:	y4			}5	 5	* 5	 4		 4	: 4		 5	 5	* 5	 4		 4	: 4		 5	 5	* 5	 4		 4	: 4		 5	 5	* 5	 4		 4	: 4		 5	 5	* 5	 4		 6	,	9	,	:	 ,	$>	(>	 0	*  g  nameg  
consequent C6>5?8 
  h     - 1 3 O O Q Q   "  5(  45"  ,	45 "" C          g  sym
			| g  clauses			| g  inline-args			| g  
consequent			| g  in		7	l g  out		7	l  g  filenamef  language/tree-il/primitives.scm

	(?		7B		=C		>D		BD	'	ED	!	GD		NE		QF	"	TF	,	UF	"	VG	%	[G	1	^G	%	aF	"	dF		lE		lB		oB	-	wB		x?	 			|
   C    h   t   ]	4 5L 4?6l       g  args
		 g  v			  g  filenamef  language/tree-il/primitives.scm	
 		   CBC   h(   r   ]	4 5$   O @ 6 j       g  y
		' g  tmp		'  g  filenamef  language/tree-il/primitives.scm

 		'   C5'R4iiJ9E7     hP   Z   -  1  3  $  =  $  *(  !454
5 6CCC R       g  expr
			O g  w		M g  x			M g  w		+	I  			O


   C>  "  G  4iiK9G7      hP   Z   -  1  3  $  =  $  *(  !454
5 6CCC R       g  expr
			O g  w		M g  x			M g  w		+	I  			O


   C>  "  G  4iiL9F7      hP   Z   -  1  3  $  =  $  *(  !454
5 6CCC R       g  expr
			O g  w		M g  x			M g  w		+	I  			O


   C>  "  G  4iiMFHJ9MKLRQ?7 
h  N  -  1  3 " O" "   $    $  $  45$  45"  $  	"  $  C"  x
$  L45	$  :	(  1	
454455
 6CC	$  		

	"C
	"yCCC $    $  $  (  "  45 6"  T45$  E45&  4	5 6	45&  4
5 6""45$  E45&  4	5 6	45&  4
5 6"\"X"	""" $  9  $  $(  45 6""" $   (   
6""  F      g  expr
		~ g  w	" g  x		" g  w		3	 g  x		3	 g  w		D g  x		D g  tail-len		O g  len		d g  ls		   g  n	
   g  p-ls	   g  z	   g  w	
   g  w	   g  w g  x	 g  w	+ g  x	+ g  w	@ g  w%X g  x	%X g  w	:P g  wmv  g  filenamef  language/tree-il/primitives.scma\	m\	*w\	^	.^	X	X	"X	Z	&Z	 		~


   C>  "  G  4iiNFHJ9N7? 	      h`  a  -  1  3 "   $    $  $  45$  45"  $  	"  $  C"  x
$  L45	$  :	(  1	
454455
 6CC	$  		

	"C
	"yCCC $  L (   6  $  $(  45 6"""    Y      g  expr
		\ g  w	 g  x		 g  w		+ g  x		+ g  w		<  g  x		<  g  tail-len		G  g  len		\  g  ls			x  g  n	
	x  g  p-ls		x  g  z	   g  w	
   g  w	   g  w g  w%X g  x	%X g  w	:P  		\


   C>  "  G  4iiOFHJ9OKLQ7      h    -  1  3 " "   $    $  $  45$  45"  $  	"  $  C"  x
$  L45	$  :	(  1	
454455
 6CC	$  		

	"C
	"yCCC $    $  r$  ](  R"  45 645$  $45&  4	5 6""""~"z"v $  A  $  ,(  !454

5 6"."*"&       g  expr
		 g  w	 g  x		 g  w		/ g  x		/ g  w		@ g  x		@ g  tail-len		K g  len		` g  ls			|  g  n	
	|  g  p-ls		|  g  z	   g  w	
   g  w	   g  w g  x	 g  w	' g  x	' g  w	< g  w g  x	 g  w	  g  filenamef  language/tree-il/primitives.scmYj	ej	"oj	 		


   C>  "  G  4iiPFHJ9P7  hX  Q  -  1  3 "   $    $  $  45$  45"  $  	"  $  C"  x
$  L45	$  :	(  1	
454455
 6CC	$  		

	"C
	"yCCC $  A  $  ,(  !4545 6"""       I      g  expr
		Q g  w	 g  x		 g  w		+ g  x		+ g  w		<  g  x		<  g  tail-len		G  g  len		\  g  ls			x  g  n	
	x  g  p-ls		x  g  z	   g  w	
   g  w	   g  wM g  x	M g  w	'E  		Q


   C>  "  G  4iiXFHJ9X7      h    -  1  3 " W"   $    $  $  45$  45"  $  	"  $  C"  x
$  L45	$  :	(  1	
454455
 6CC	$  		

	"C
	"yCCC $  P  $  ;$  &(  45 6"""" $  T (   
6  $  ,(  !454
5 6"R"N"J           g  expr
		 g  w	 g  x		 g  w		/ g  x		/ g  w		@ g  x		@ g  tail-len		K g  len		` g  ls			|  g  n	
	|  g  p-ls		|  g  z	   g  w	
   g  w	   g  w` g  x	` g  w	'\ g  x	'\ g  w	<T g  wu~ g  w g  x	 g  w	  		


   C>  "  G  4iiWFHJ9W7  h    -  1  3 " W"   $    $  $  45$  45"  $  	"  $  C"  x
$  L45	$  :	(  1	
454455
 6CC	$  		

	"C
	"yCCC $  P  $  ;$  &(  45 6"""" $  V (  
 	6  $  -(  "454	5 6"P"L"H         g  expr
		 g  w	 g  x		 g  w		/ g  x		/ g  w		@ g  x		@ g  tail-len		K g  len		` g  ls			|  g  n	
	|  g  p-ls		|  g  z	   g  w	
   g  w	   g  w` g  x	` g  w	'\ g  x	'\ g  w	<T g  wu g  w g  x	 g  w	  		


   C>  "  G  4ii9|      h`   Z   -  1  3  $  H  $  5(  ,45445 5 6CCC      R       g  expr
			Z g  w		X g  x			X g  w		+	T  			Z


   C>  "  G  4ii9|}       h`   Z   -  1  3  $  H  $  5(  ,45445 5 6CCC      R       g  expr
			Z g  w		X g  x			X g  w		+	T  			Z


   C>  "  G  4ii9}|       h`   Z   -  1  3  $  H  $  5(  ,45445 5 6CCC      R       g  expr
			Z g  w		X g  x			X g  w		+	T  			Z


   C>  "  G  4ii9} h`   Z   -  1  3  $  H  $  5(  ,45445 5 6CCC      R       g  expr
			Z g  w		X g  x			X g  w		+	T  			Z


   C>  "  G  4ii9| hp   Z   -  1  3  $  [  $  H(  ?45445445 5 5 6CCC   R       g  expr
			m g  w		k g  x			k g  w		+	g  			m


   C>  "  G  4ii9|}       hp   Z   -  1  3  $  [  $  H(  ?45445445 5 5 6CCC   R       g  expr
			m g  w		k g  x			k g  w		+	g  			m


   C>  "  G  4ii9|}       hp   Z   -  1  3  $  [  $  H(  ?45445445 5 5 6CCC   R       g  expr
			m g  w		k g  x			k g  w		+	g  			m


   C>  "  G  4ii9|}       hp   Z   -  1  3  $  [  $  H(  ?45445445 5 5 6CCC   R       g  expr
			m g  w		k g  x			k g  w		+	g  			m


   C>  "  G  4ii9}|       hp   Z   -  1  3  $  [  $  H(  ?45445445 5 5 6CCC   R       g  expr
			m g  w		k g  x			k g  w		+	g  			m


   C>  "  G  4ii9}|       hp   Z   -  1  3  $  [  $  H(  ?45445445 5 5 6CCC   R       g  expr
			m g  w		k g  x			k g  w		+	g  			m


   C>  "  G  4ii9}|       hp   Z   -  1  3  $  [  $  H(  ?45445445 5 5 6CCC   R       g  expr
			m g  w		k g  x			k g  w		+	g  			m


   C>  "  G  4ii9} hp   Z   -  1  3  $  [  $  H(  ?45445445 5 5 6CCC   R       g  expr
			m g  w		k g  x			k g  w		+	g  			m


   C>  "  G  4ii9| h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9|}     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9|}     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9|}     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9|}     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9|}     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9|}     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9|}     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9}|     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9}|     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9}|     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9}|     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9}|     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9}|     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9}|     h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4ii9}       h   \   -  1  3  $  n  $  [(  R45445445445 5 5 5 6CCCT       g  expr
		  g  w		~ g  x			~ g  w		+	z  		 


   C>  "  G  4iiy9xy?   h    -  1  3 "  "  b $  Y  $  F$  3454455 6CCC $  P  $  ;$  &(  45 6"O"K"G"C $  9  $  $(  45 6"""            g  expr
		 g  w		q g  x			q g  w		/	o g  x		/	o g  w		@	m g  x		@	m g  w   g  x	   g  w	   g  x	   g  w	   g  w  g  x	  g  w	   		


   C>  "  G  4iiw9x    h      -  1  3  $  r  $  _$  L$  9(  045445 5 6CCCCC           g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8	~ g  x		8	~ g  w		M	z  		 


   C>  "  G  4ii697       h`      -  1  3  $  G  $  4$  !456CCC              g  expr
			Y g  w		W g  x			W g  w		'	U g  x		'	U g  w		8	S g  x		8	S  			Y


   C>  "  G  4ii899    h`   x   -  1  3  $  J  $  7$  $(  45 6CCCC    p       g  expr
			\ g  w		Z g  x			Z g  w		'	X g  x		'	X g  w		<	T  			\


   C>  "  G  4ii:9;   hH   Z   -  1  3  $  5  $  "(  45 6CCC R       g  expr
			G g  w		E g  x			E g  w		+	A  			G


   C>  "  G  4ii<9; hH   Z   -  1  3  $  5  $  "(  45 6CCC R       g  expr
			G g  w		E g  x			E g  w		+	A  			G


   C>  "  G  4iiKLck9       h   !  -  1  3  $    $  t$  a45$  J4545$  45$  
"  "  $  456CCCCC             g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  n		N	w  g  filenamef  language/tree-il/primitives.scm	=		H		N		Q		[	
	\		f	
	i	)	{	 
		 


   C>  "  G  4ii9  h`   x   -  1  3  $  J  $  7$  $(  45 6CCCC    p       g  expr
			\ g  w		Z g  x			Z g  w		'	X g  x		'	X g  w		<	T  			\


   C>  "  G  4ii9   hx      -  1  3  $  _  $  L$  9$  &(  45 6CCCCC              g  expr
			q g  w		o g  x			o g  w		'	m g  x		'	m g  w		8	k g  x		8	k g  w		M	g  			q


   C>  "  G  4ii9     h`   x   -  1  3  $  J  $  7$  $(  45 6CCCC    p       g  expr
			\ g  w		Z g  x			Z g  w		'	X g  x		'	X g  w		<	T  			\


   C>  "  G  4ii9   hx      -  1  3  $  _  $  L$  9$  &(  45 6CCCCC              g  expr
			q g  w		o g  x			o g  w		'	m g  x		'	m g  w		8	k g  x		8	k g  w		M	g  			q


   C>  "  G  4ii9N7        hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  4ii9N7       hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  4ii9N7       hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  4ii9N7       hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  4ii9N7       hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  4ii9N7       hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  4ii9N7       hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  4ii9N7       hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  4ii9N7       hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  4ii9N7       hx   x   -  1  3  $  f  $  S$  @(  7454454	5 5 6CCCCp       g  expr
			x g  w		v g  x			v g  w		'	t g  x		'	t g  w		<	p  			x


   C>  "  G  4ii9N7      h      -  1  3  $  {  $  h$  U$  B(  9454454	5 5 6CCCCC          g  expr
		  g  w	  g  x		  g  w		'  g  x		'  g  w		8  g  x		8  g  w		M   		 


   C>  "  G  7MNOPQRS9 h   0  )   
3  6)   3 C)   3 C- 1 3 4 L 5454 5   4	 4
  54
 54 556 (      g  src
			 g  src
		 g  a		 g  src
	$	& g  a	$	& g  b		$	& g  src
	/  g  a	/  g  b		/  g  rest		/  g  prim		8  g  b-sym		A  g  b*		N   
g  filenamef  language/tree-il/primitives.scm
						0		8		;		?		A		A		D		J	&	N		N		V		[		`		a		f	#	s	>	u	#	v	# 	> 	# 	# 	 	 			 			 	$	&	 	/ 	
	   C     h      ] O C             g  	prim-name
		
  g  filenamef  language/tree-il/primitives.scm

 		
  g  nameg  chained-comparison-expander CTR4iT h   }   ] 4 56       u       g  	prim-name
		  g  filenamef  language/tree-il/primitives.scm
	
				 	 		   CU>  "  G  KLCVjkWX9@ h   e  ]4 5$  |4 545$  "  ?$  "  345$  '45$  $  	"  "  "  $  	L 4
5  6CC     ]      g  a
	  g  b	  g  v		  g  t			n  g  filenamef  language/tree-il/primitives.scm
			
		

										/
		3		4
		9		C		D		N		S		r		w	)	|	@	~	) 	% 	 	 	  g  nameg  maybe-simplify C        h@     )   ,3 O  Q 45$  C6-  1  3 C         g  src
			2 g  a			2 g  b				2 g  maybe-simplify			2 g  t			2 g  else
	;	=  g  filenamef  language/tree-il/primitives.scm
							2		;	 			2	 	;	=


  g  nameg  maybe-simplify-to-eq CYR4iiAYi>  "  G  4iiBYi>  "  G  4ii=MZ[\Q`aO]9^_ 
     hx     )   d3 454545   4 4	54
4554556-  1  3 C         g  src
			j g  pre			j g  thunk				j g  post				j g  PRE			j g  THUNK			j g  POST			j g  else
	s	u  g  filenamef  language/tree-il/primitives.scm
		
			"						$						#					*"		3#		<$		=%		B'		G'	(	K'		L(		P(	(	U(	=	Y(	(	Z(	K	\(		])		b)	(	f)		h%		j 		s	 			j	 	s	u


   C>  "  G  4ii>MZ\QbaO]_ 
      hH   h  ]4545   4 454	556 `      g  src
		G g  pre		G g  expr			G g  post			G g  PRE			G g  POST			G  g  filenamef  language/tree-il/primitives.scm
.		0		0	"		0		
1		1	#	1		0		4		!5		(6		)7		.9		39	(	79		:;		?;	(	C;		E7		G2	 		G	   C>  "  G  4iic        h       )   3  6-  1  3 C           g  src
			 g  fluid			 g  else
		  g  filenamef  language/tree-il/primitives.scm
?		@		?	 				 		


   C>  "  G  4iid   h       )   
3  6-  1  3 C         g  src
			 g  fluid			 g  exp				 g  else
		  g  filenamef  language/tree-il/primitives.scm
E		F		E	 				 		


   C>  "  G  4iiMefgh96O 
  h`     )   I3 45  445 4454	5 55	6-  1  3 C      y      g  src
			O g  tag			O g  exp				O g  handler				O g  args-sym			O g  else
	X	Z  g  filenamef  language/tree-il/primitives.scm
K		
M		M		R		S		#S	)	&S	0	(S	9	-S	=	.T		2T	(	7T	?	9T	(	<V	+	AV	@	EV	+	HU	%	JT		MR		ON		XK	 			O	 	X	Z


   C>  "  G  4iiMQje9fgh6Oi 
      h   
  )   r3 45 45    4 45445 44	
54545 55	56-  1  3 C           g  src
			x g  tag			x g  thunk				x g  handler				x g  handler-sym			x g  args-sym			x g  else
    g  filenamef  language/tree-il/primitives.scm
\		
^	"	_		^		a		"a	!	'a	4	(b		/c		5c	6	7c		8f		;g		Bg	*	Eg	1	Gg	:	Lg	>	Mh		Qi		Vi	/	Xi		Yj		^j	0	bj		ck		hk	0	lk		oj		qh		tf		vb		x`	 \	 "			x	   


   C>  "  G  4iik   h       )   3  6-  1  3 C        g  src
			 g  tag			 g  	tail-args				 g  else
		  g  filenamef  language/tree-il/primitives.scm
q		s	#	s		q	 				 		


   C>  "  G  iik7   h(      *   1 3  456-  1  3 C       g  src
		 g  tag		 g  args			 g  else
	&	(  g  filenamef  language/tree-il/primitives.scm
w		y	(	y	7	y	(	y		&w	 			
	 	&	(


   C6   Z      g  m
		,  g  filenamef  language/tree-il/primitives.scm		
	.	&		1	%
\	t
]	z	%f	z
g	|
 		~
 	 
 	 
 	 
 	 
 	 
 	 
 	& 
 	1 
 	* 
 	" 
 	$ 
 
 
6 
 
 
4 
 
 
	f 

/ 

 
 
g 
h	!r
	
	J
M
P
 U
%c
(h
,o
/s
3y
7;
8(
9
:
:
;
<
=
>
?
@
A
B
C
D
F

G
H*
I:
JJ
KZ
Lj
Mz
N
O
P
Q
R
S
V5
W
X
Y
Z
[P
]O
^V
_
`
a
c
dm
e
f
h&
i
j
l
mF
n
o
q=
rf
s
t
v]
w
x
z


	

      b
      c
      n	%      x
      
      	%      
      
      	      N
      W,
      b-	      E,
      N=
      Y>	      :=
      CC
      ND	      ;C
      DI
      OJ	      ^I
      gZ
      r[	      BZ
      Ko
      Vp	      Po
      cv	      uu
 	      u
   C6 